# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`openospfd`](#openospfd): main class to configure openospfd
* [`openospfd::ospf6d`](#openospfd--ospf6d): main class to configure ospf6d
* [`openospfd::ospfd`](#openospfd--ospfd): main class to configure ospfd

### Defined types

* [`openospfd::area`](#openospfd--area): add an area to the config
* [`openospfd::interface`](#openospfd--interface): add an interface to an area

## Classes

### <a name="openospfd"></a>`openospfd`

This is the main class to configure openospfd.
Parameters set here are used as defaults for
ospfd and ospf6d configuration. They can all be
overwritten in opfd respective ospf6d class.

#### Examples

##### 

```puppet
include openospfd
```

#### Parameters

The following parameters are available in the `openospfd` class:

* [`include_ospfd`](#-openospfd--include_ospfd)
* [`include_ospf6d`](#-openospfd--include_ospf6d)
* [`owner`](#-openospfd--owner)
* [`group`](#-openospfd--group)
* [`areas`](#-openospfd--areas)
* [`router_id`](#-openospfd--router_id)
* [`rdomain`](#-openospfd--rdomain)
* [`rtable`](#-openospfd--rtable)
* [`macros`](#-openospfd--macros)
* [`global_config`](#-openospfd--global_config)
* [`rcconffile`](#-openospfd--rcconffile)
* [`interfaces`](#-openospfd--interfaces)

##### <a name="-openospfd--include_ospfd"></a>`include_ospfd`

Data type: `Boolean`

whether to include/configure ospfd

Default value: `true`

##### <a name="-openospfd--include_ospf6d"></a>`include_ospf6d`

Data type: `Boolean`

whether to include/configure ospf6d

Default value: `true`

##### <a name="-openospfd--owner"></a>`owner`

Data type: `String`

owner of the configuration files

Default value: `'root'`

##### <a name="-openospfd--group"></a>`group`

Data type: `String`

group of the configuration files

Default value: `'wheel'`

##### <a name="-openospfd--areas"></a>`areas`

Data type: `Hash`

areas to set up
this Hash is used to run openospfd::area resource

Default value: `{}`

##### <a name="-openospfd--router_id"></a>`router_id`

Data type: `Optional[String]`

the router-id

Default value: `undef`

##### <a name="-openospfd--rdomain"></a>`rdomain`

Data type: `Optional[String]`

the rdomain to set

Default value: `undef`

##### <a name="-openospfd--rtable"></a>`rtable`

Data type: `Optional[String]`

the rdomain to start in (set ospfd_rtable in rc.conf.local)

Default value: `undef`

##### <a name="-openospfd--macros"></a>`macros`

Data type: `Hash`

Hash of macros to define

Default value: `{}`

##### <a name="-openospfd--global_config"></a>`global_config`

Data type: `Hash`

Hash of global configurations

Default value: `{}`

##### <a name="-openospfd--rcconffile"></a>`rcconffile`

Data type: `String`

the rc.conf file to write startup parameters into

Default value: `'/etc/rc.conf.local'`

##### <a name="-openospfd--interfaces"></a>`interfaces`

Data type: `Hash`

default interfaces to add to the area (using openospfd::interface)
for detailed interface options see openospfd::interface

Default value: `{}`

### <a name="openospfd--ospf6d"></a>`openospfd::ospf6d`

This class configures ospfd.
It takes default values from ::openospfd class

#### Parameters

The following parameters are available in the `openospfd::ospf6d` class:

* [`config_file`](#-openospfd--ospf6d--config_file)
* [`service_name`](#-openospfd--ospf6d--service_name)
* [`service_ensure`](#-openospfd--ospf6d--service_ensure)
* [`service_enable`](#-openospfd--ospf6d--service_enable)
* [`validate_cmd`](#-openospfd--ospf6d--validate_cmd)
* [`areas`](#-openospfd--ospf6d--areas)
* [`router_id`](#-openospfd--ospf6d--router_id)
* [`rdomain`](#-openospfd--ospf6d--rdomain)
* [`rtable`](#-openospfd--ospf6d--rtable)
* [`macros`](#-openospfd--ospf6d--macros)
* [`global_config`](#-openospfd--ospf6d--global_config)
* [`redistribute`](#-openospfd--ospf6d--redistribute)

##### <a name="-openospfd--ospf6d--config_file"></a>`config_file`

Data type: `String`



Default value: `'/etc/ospf6d.conf'`

##### <a name="-openospfd--ospf6d--service_name"></a>`service_name`

Data type: `String`

the name of the ospfd service

Default value: `'ospf6d'`

##### <a name="-openospfd--ospf6d--service_ensure"></a>`service_ensure`

Data type: `String`

what we ensure for the service

Default value: `'running'`

##### <a name="-openospfd--ospf6d--service_enable"></a>`service_enable`

Data type: `String`

should the service be enabled

Default value: `'true'`

##### <a name="-openospfd--ospf6d--validate_cmd"></a>`validate_cmd`

Data type: `String`

command to validate the configuration file

Default value: `'/usr/sbin/ospf6d -nf %'`

##### <a name="-openospfd--ospf6d--areas"></a>`areas`

Data type: `Optional[Hash]`

Hash of areas to set up with openospfd::area
resource.

Default value: `undef`

##### <a name="-openospfd--ospf6d--router_id"></a>`router_id`

Data type: `Optional[String]`

the router-id

Default value: `undef`

##### <a name="-openospfd--ospf6d--rdomain"></a>`rdomain`

Data type: `Optional[String]`

the rdomain to set

Default value: `undef`

##### <a name="-openospfd--ospf6d--rtable"></a>`rtable`

Data type: `Optional[String]`

the rdomain to start in (set ospfd_rtable in rc.conf.local)

Default value: `undef`

##### <a name="-openospfd--ospf6d--macros"></a>`macros`

Data type: `Optional[Hash]`

Hash of macros to define

Default value: `undef`

##### <a name="-openospfd--ospf6d--global_config"></a>`global_config`

Data type: `Optional[Hash]`

Hash of global configurations

Default value: `undef`

##### <a name="-openospfd--ospf6d--redistribute"></a>`redistribute`

Data type: `Optional[Array]`

Array of hashes for redistribute vals
one hash has the following keys available:
value: one of static|connected|default or a prefix or 'rtlabel label'
set: hash of settings (eg metric: 300)
depend: interface name to depend on
negativ: boolean, if set to true, the rule is a 'no redistribute' rule'
exampel in yaml notation:

- value: 'static'
  set:
    metric: '300'
    type: '2'
  depend: 'carp3'

Default value: `[]`

### <a name="openospfd--ospfd"></a>`openospfd::ospfd`

This class configures ospfd.
It takes default values from ::openospfd class

#### Parameters

The following parameters are available in the `openospfd::ospfd` class:

* [`config_file`](#-openospfd--ospfd--config_file)
* [`service_name`](#-openospfd--ospfd--service_name)
* [`service_ensure`](#-openospfd--ospfd--service_ensure)
* [`service_enable`](#-openospfd--ospfd--service_enable)
* [`validate_cmd`](#-openospfd--ospfd--validate_cmd)
* [`areas`](#-openospfd--ospfd--areas)
* [`router_id`](#-openospfd--ospfd--router_id)
* [`rdomain`](#-openospfd--ospfd--rdomain)
* [`rtable`](#-openospfd--ospfd--rtable)
* [`macros`](#-openospfd--ospfd--macros)
* [`global_config`](#-openospfd--ospfd--global_config)
* [`redistribute`](#-openospfd--ospfd--redistribute)

##### <a name="-openospfd--ospfd--config_file"></a>`config_file`

Data type: `String`



Default value: `'/etc/ospfd.conf'`

##### <a name="-openospfd--ospfd--service_name"></a>`service_name`

Data type: `String`

the name of the ospfd service

Default value: `'ospfd'`

##### <a name="-openospfd--ospfd--service_ensure"></a>`service_ensure`

Data type: `String`

what we ensure for the service

Default value: `'running'`

##### <a name="-openospfd--ospfd--service_enable"></a>`service_enable`

Data type: `String`

should the service be enabled

Default value: `'true'`

##### <a name="-openospfd--ospfd--validate_cmd"></a>`validate_cmd`

Data type: `String`

command to validate the configuration file

Default value: `'/usr/sbin/ospfd -nf %'`

##### <a name="-openospfd--ospfd--areas"></a>`areas`

Data type: `Optional[Hash]`

Hash of areas to set up with openospfd::area
resource.

Default value: `undef`

##### <a name="-openospfd--ospfd--router_id"></a>`router_id`

Data type: `Optional[String]`

the router-id

Default value: `undef`

##### <a name="-openospfd--ospfd--rdomain"></a>`rdomain`

Data type: `Optional[String]`

the rdomain to set

Default value: `undef`

##### <a name="-openospfd--ospfd--rtable"></a>`rtable`

Data type: `Optional[String]`

the rdomain to start in (set ospfd_rtable in rc.conf.local)

Default value: `undef`

##### <a name="-openospfd--ospfd--macros"></a>`macros`

Data type: `Optional[Hash]`

Hash of macros to define

Default value: `undef`

##### <a name="-openospfd--ospfd--global_config"></a>`global_config`

Data type: `Optional[Hash]`

Hash of global configurations

Default value: `undef`

##### <a name="-openospfd--ospfd--redistribute"></a>`redistribute`

Data type: `Optional[Array]`

Array of hashes for redistribute vals
one hash has the following keys available:
value: one of static|connected|default or a prefix or 'rtlabel label'
set: hash of settings (eg metric: 300)
depend: interface name to depend on
negativ: boolean, if set to true, the rule is a 'no redistribute' rule'
exampel in yaml notation:

- value: 'static'
  set:
    metric: '300'
    type: '2'
  depend: 'carp3'
- value: '10.0.0.0/8'
  negativ: true

Default value: `[]`

## Defined types

### <a name="openospfd--area"></a>`openospfd::area`

add an area to the config

#### Parameters

The following parameters are available in the `openospfd::area` defined type:

* [`target`](#-openospfd--area--target)
* [`area_name`](#-openospfd--area--area_name)
* [`config`](#-openospfd--area--config)
* [`interfaces`](#-openospfd--area--interfaces)

##### <a name="-openospfd--area--target"></a>`target`

Data type: `String`

the target to write the area into

##### <a name="-openospfd--area--area_name"></a>`area_name`

Data type: `String`

the name of the area

Default value: `$title`

##### <a name="-openospfd--area--config"></a>`config`

Data type: `Hash`

area specific configuration

Default value: `{}`

##### <a name="-openospfd--area--interfaces"></a>`interfaces`

Data type: `Hash`

interfaces to add to the area (using openospfd::interface)
for detailed interface options see openospfd::interface

Default value: `{}`

### <a name="openospfd--interface"></a>`openospfd::interface`

adds an interface to an area.
this define is used internaly from
openospfd::area (but it's also possible to use it
from youre toplevel.

#### Parameters

The following parameters are available in the `openospfd::interface` defined type:

* [`target`](#-openospfd--interface--target)
* [`area_name`](#-openospfd--interface--area_name)
* [`interface_name`](#-openospfd--interface--interface_name)
* [`config`](#-openospfd--interface--config)
* [`passive`](#-openospfd--interface--passive)

##### <a name="-openospfd--interface--target"></a>`target`

Data type: `String`

the target file

##### <a name="-openospfd--interface--area_name"></a>`area_name`

Data type: `String`

the name of the area to add the interface

##### <a name="-openospfd--interface--interface_name"></a>`interface_name`

Data type: `String`

the name of the interface to add

Default value: `$title`

##### <a name="-openospfd--interface--config"></a>`config`

Data type: `Hash`

the interface specific configuration

Default value: `{}`

##### <a name="-openospfd--interface--passive"></a>`passive`

Data type: `Boolean`

set to true for passive interface

Default value: `false`

